﻿local addonName, addonTable = ...
local L = addonTable.L
local addon = PriorityList
local AceGUI = LibStub("AceGUI-3.0")

-- string colors
local LIGHT_BLUE  = "|cff00ccff"
local LIGHT_RED   = "|cffff6060"
local GREEN       = "|cff71C671"
local LIGHT_GREEN = "|cff71FF71"
local YELLOW      = "|cffffff00"
local GREY        = "|cff888888"
local GOLD        = "|cffffcc00"
local RED         = "|cffff0000"
local function AddColor(str,color)
 return color..str.."|r"
end

addon.opt = {}

function addon:AddChar(name,tab,refresh)
 local chartable = tab
-- if chartable == nil then chartable = {} end
 if not PLWish_List[name] then
  PLWish_List[name] = {}
  if chartable ~= nil then
   table.foreach(chartable,function(k,v) table.insert(PLWish_List[name], v) end)   
  end
  if refresh then
--   if addon.opt.edt_search then addon.opt.edt_search:SetText(name) end
   addon:GenerateItemsList("main")
   addon:PopulateItemsList_new()
  end
 else
  addon:SetStatus(L["charexists"])
 end
end

function addon:RenameChar(name,newname,refresh)
  local renamechar = function() 
                      addon:AddChar(newname,PLWish_List[name],false)
                      addon:DeleteChar(name,false) 
                      if refresh then
                       addon:GenerateItemsList("main")
                       addon:PopulateItemsList_new()
                      end
                     end
 if PLWish_List[name] and not PLWish_List[newname] then
  addon:ConfirmCheck(renamechar)
 end
end

function addon:DeleteChar(name, refresh)
 local deletechar = function()
                     table.foreach(PLWish_List[name],
                     function(k,v)
                      if addon.waiting_ids[v] ~= nil then
                       addon:CancelTimer(addon.waiting_ids[v]["timer"],true)
                       addon.waiting_ids[v] = nil
                      end
                     end)
                     PLWish_List[name] = nil
                     if refresh then
                      addon:GenerateItemsList("main")
                      addon:PopulateItemsList_new()
                     end                     
                    end
 if PLWish_List[name] ~= nil then
  -- if it doesn't refresh the list, it's a way to rename a char or deleting the whole list and it doesn't require additional confirms
  if refresh then addon:ConfirmCheck(deletechar) else deletechar() end
 end
end

function addon:MoveItem(name, index, direction, refresh)
 if PLWish_List[name] then
  local tmp_item = PLWish_List[name][index]
  if direction == "up" then
   PLWish_List[name][index]   = PLWish_List[name][index-1]
   PLWish_List[name][index-1] = tmp_item
  elseif direction == "down" then
   PLWish_List[name][index]   = PLWish_List[name][index+1]
   PLWish_List[name][index+1] = tmp_item
  end
  if refresh then
   addon:GenerateItemsList("main")
   addon:PopulateItemsList_new()
  end
 end
end

-- wish list tab creation
function addon:TabInit_WishList(container)
if container then

-- buttons panel
 addon.opt.upperpanel = AceGUI:Create("SimpleGroup")
 addon.opt.upperpanel:SetFullWidth(true)
 addon.opt.upperpanel:SetLayout("Flow")
 container:AddChild(addon.opt.upperpanel)
--add char button
 addon.opt.btn_addchar = AceGUI:Create("Button")
 addon.opt.btn_addchar:SetText(L["wl_addchar"])
 addon.opt.btn_addchar:SetWidth(150)
 addon.opt.btn_addchar:SetCallback("OnClick",
  function(widget) --add char onclick
   if not addon:IsSimpleMode() then
    local dialog = StaticPopup_Show("pl_textdialog")
    if dialog then
     dialog.data = "add"
     dialog.data2 = ""
     dialog.text:SetText(L["add"].." "..L["char"])
    end
   else
    local p = UnitName("player")
    if not PLWish_List[p] then
     addon:AddChar(p,{},true)
    end
   end
  end)
 addon.opt.upperpanel:AddChild(addon.opt.btn_addchar)

--export button
 addon.opt.btn_export = AceGUI:Create("Button")
 addon.opt.btn_export:SetText(L["exportbtn"])
 addon.opt.btn_export:SetWidth(150)
 addon.opt.btn_export:SetCallback("OnClick",
  function(widget) --export onclick
 local menuFrame = CreateFrame("Frame", "PLButtonMenuFrame", UIParent, "UIDropDownMenuTemplate")
 local function CreateSubMenu_Exp()

   local function mn_char_msg(channel)
    return { text = channel,notCheckable = 1, func = function()
     addon.import_var.tosend = nil
     if addon:IsSimpleMode() then
      local p = UnitName("player")
      if PLWish_List[p] then -- simple mode, exports only the playing character
       addon.import_var.tosend = {[p] = PLWish_List[p]}
      end
     else -- officer mode, exports the whole list
      addon.import_var.tosend = PLWish_List
     end
     if addon.import_var.tosend then
      if channel ~= L["Whisper"] then
       addon:SendCommMessage("PriorityList", "::msg:request"..PriorityList.version, channel, "")
       addon:StartExportTimer();
      else --whisper dialog
       local dialog = StaticPopup_Show("pl_textdialog")
       if dialog then
        dialog.data = "export"
        dialog.text:SetText(L["export"].." <"..L["all"].."> "..L["to"])
       end
      end
     end
     if menuFrame then menuFrame:Hide() end
    end}
   end
   
  return {mn_char_msg(L["Officer"]),
          mn_char_msg(L["Guild"]),
          mn_char_msg(L["Raid"]),
          mn_char_msg(L["Party"]),
          mn_char_msg(L["Whisper"]),}
 end
   local menu = {}
   table.insert(menu,{text = L["exportvia"], notCheckable = 1, hasArrow = true,menuList = CreateSubMenu_Exp()})
   EasyMenu(menu, menuFrame, "cursor", 0 , 0, "MENU")
  end)
 addon.opt.upperpanel:AddChild(addon.opt.btn_export)
-- export button end

 addon.opt.edt_search:Show()
 addon.opt.edt_search_clear:Show()
 addon.opt.frm_items = AceGUI:Create("ScrollFrame")
 addon.opt.frm_items:SetFullWidth(true)
 addon.opt.frm_items:SetFullHeight(true)
 addon.opt.frm_items:SetLayout("List")
 container:AddChild(addon.opt.frm_items)

 addon:PopulateItemsList_new()
end
end
-- wish list tab creation end